@@ -7,22 +7,17 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KCMTODOSUMMARY_H
-#define KCMTODOSUMMARY_H
+#pragma once
 
 #include "ui_todosummaryconfig_base.h"
 #include <KCModule>
 
-extern "C" {
-Q_DECL_EXPORT KCModule *create_todosummary(QWidget *parent, const char *);
-}
-
 class KCMTodoSummary : public KCModule, public Ui::TodoSummaryConfig_Base
 {
     Q_OBJECT
 
 public:
-    explicit KCMTodoSummary(QWidget *parent = nullptr);
+    explicit KCMTodoSummary(QWidget *parent = nullptr, const QVariantList &args = {});
     ~KCMTodoSummary() override;
 
     void load() override;
@@ -35,4 +30,3 @@ private Q_SLOTS:
     void customDaysChanged(int value);
 };
 
-#endif
