@@ -4,9 +4,10 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KORGMIGRATEAPPLICATION_H
-#define KORGMIGRATEAPPLICATION_H
-
+#pragma once
+#include <QObject>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "korganizerprivate_export.h"
 #include <PimCommon/MigrateApplicationFiles>
 
@@ -21,5 +22,4 @@ private:
     void initializeMigrator();
     PimCommon::MigrateApplicationFiles mMigrator;
 };
-
-#endif // KORGMIGRATEAPPLICATION_H
+#endif
